@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,12 +68,9 @@ public class CurrencyNames_am extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AUD", "AU$" },
-            { "CNH", "\u12e8\u127b\u12ed\u1293 \u12e9\u12cb\u1295" },
             { "ETB", "\u1265\u122d" },
-            { "MRU", "MRU" },
-            { "STN", "STN" },
+            { "PHP", "PHP" },
             { "THB", "\u0e3f" },
-            { "VES", "VES" },
             { "aed", "\u12e8\u1270\u1263\u1260\u1229\u1275 \u12e8\u12a0\u1228\u1265 \u12a4\u121d\u122c\u1275\u1235 \u12f5\u122d\u1200\u121d" },
             { "afn", "\u12e8\u12a0\u134d\u130b\u1295 \u12a0\u134d\u130b\u1292" },
             { "all", "\u12e8\u12a0\u120d\u1263\u1295\u12eb \u120c\u12ad" },
@@ -137,7 +130,7 @@ public class CurrencyNames_am extends OpenListResourceBundle {
             { "gyd", "\u12e8\u1309\u12e8\u1293 \u12f6\u120b\u122d" },
             { "hkd", "\u12e8\u1206\u1295\u130d\u12ae\u1295\u130d \u12f6\u120b\u122d" },
             { "hnl", "\u12e8\u1203\u1295\u12f1\u122b \u120c\u121d\u1353\u12a0\u12ed\u122b" },
-            { "hrk", "HRK" },
+            { "hrk", "\u12e8\u12ad\u122e\u123d\u12eb \u12a9\u1293" },
             { "htg", "\u12e8\u1203\u12eb\u1272 \u1313\u122d\u12f4" },
             { "huf", "\u12e8\u1203\u1295\u130b\u122a\u12eb\u1295 \u134e\u122a\u1295\u1275" },
             { "idr", "\u12e8\u12a2\u1295\u12f6\u1294\u12e5\u12eb \u1229\u1352\u1203" },
@@ -208,7 +201,8 @@ public class CurrencyNames_am extends OpenListResourceBundle {
             { "sek", "\u12e8\u1235\u12ca\u12f5\u1295 \u12ad\u122e\u1293" },
             { "sgd", "\u12e8\u1232\u1295\u130b\u1356\u122d \u12f6\u120b\u122d" },
             { "shp", "\u12e8\u1234\u12ed\u1295\u1275 \u1214\u120c\u1293 \u1353\u12cd\u1295\u12f5" },
-            { "sll", "\u12e8\u1234\u122b\u120a\u12ce\u1295 \u120a\u12ce\u1295" },
+            { "sle", "\u12e8\u1234\u122b\u120a\u12ce\u1295 \u120a\u12ce\u1295" },
+            { "sll", "\u12e8\u1234\u122b\u120a\u12ce\u1295 \u120a\u12ce\u1295 (1964\u20142022)" },
             { "sos", "\u12e8\u1236\u121b\u120c \u123a\u120a\u1295\u130d" },
             { "srd", "\u12e8\u1230\u122d\u1293\u121c\u12dd \u12f6\u120b\u122d" },
             { "ssp", "\u12e8\u12f0\u1261\u1265 \u1231\u12f3\u1295 \u1353\u12cd\u1295\u12f5" },
