@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,168 +67,44 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
             { "ARS", "$AR" },
             { "AUD", "$AU" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
             { "BEF", "FB" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
             { "BMD", "$BM" },
             { "BND", "$BN" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
             { "BZD", "$BZ" },
             { "CAD", "$CA" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
             { "CLP", "$CL" },
-            { "CNH", "CNH" },
             { "CNY", "CNY" },
             { "COP", "$CO" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
             { "CYP", "\u00a3CY" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
             { "FJD", "$FJ" },
             { "FKP", "\u00a3FK" },
             { "FRF", "F" },
             { "GBP", "\u00a3GB" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
             { "GIP", "\u00a3GI" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
             { "HKD", "HKD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
             { "IEP", "\u00a3IE" },
             { "ILP", "\u00a3IL" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
             { "ITL", "\u20a4IT" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "JPY" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
             { "LBP", "\u00a3LB" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LTL", "LTL" },
-            { "LVL", "LVL" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
             { "MTP", "\u00a3MT" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
             { "MXN", "$MX" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
             { "NAD", "$NA" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
             { "NZD", "$NZ" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
             { "RHD", "$RH" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
             { "SBD", "$SB" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
             { "SGD", "$SG" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
             { "SRD", "$SR" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
             { "TTD", "$TT" },
             { "TWD", "TWD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
             { "USD", "$US" },
             { "UYU", "$UY" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VES", "VES" },
-            { "VUV", "VUV" },
             { "WST", "$WS" },
             { "XCD", "XCD" },
             { "XPF", "FCFP" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMK", "ZMK" },
-            { "ZMW", "ZMW" },
             { "adp", "peseta andorrane" },
             { "aed", "dirham des \u00c9mirats arabes unis" },
             { "afa", "afghani (1927\u20132002)" },
@@ -364,7 +236,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "kwd", "dinar kowe\u00eftien" },
             { "kyd", "dollar des \u00eeles Ca\u00efmans" },
             { "kzt", "tenge kazakh" },
-            { "lak", "kip loatien" },
+            { "lak", "kip laotien" },
             { "lbp", "livre libanaise" },
             { "lkr", "roupie srilankaise" },
             { "lrd", "dollar lib\u00e9rien" },
@@ -392,7 +264,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "mtl", "lire maltaise" },
             { "mtp", "livre maltaise" },
             { "mur", "roupie mauricienne" },
-            { "mvr", "rufiyaa maldivien" },
+            { "mvr", "rufiyaa maldivienne" },
             { "mwk", "kwacha malawite" },
             { "mxn", "peso mexicain" },
             { "mxp", "peso d\u2019argent mexicain (1861\u20131992)" },
@@ -440,7 +312,8 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "shp", "livre de Sainte-H\u00e9l\u00e8ne" },
             { "sit", "tolar slov\u00e8ne" },
             { "skk", "couronne slovaque" },
-            { "sll", "leone sierra-l\u00e9onais" },
+            { "sle", "leone sierra-l\u00e9onais" },
+            { "sll", "leone sierra-l\u00e9onais (1964\u20142022)" },
             { "sos", "shilling somalien" },
             { "srd", "dollar surinamais" },
             { "srg", "florin surinamais" },
@@ -461,7 +334,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "tpe", "escudo timorais" },
             { "trl", "livre turque (1844\u20132005)" },
             { "try", "livre turque" },
-            { "ttd", "dollar trinidadien" },
+            { "ttd", "dollar de Trinit\u00e9-et-Tobago" },
             { "twd", "nouveau dollar ta\u00efwanais" },
             { "tzs", "shilling tanzanien" },
             { "uah", "hryvnia ukrainienne" },
@@ -489,6 +362,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "xbc", "unit\u00e9 de compte europ\u00e9enne (XBC)" },
             { "xbd", "unit\u00e9 de compte europ\u00e9enne (XBD)" },
             { "xcd", "dollar des Cara\u00efbes orientales" },
+            { "xcg", "florin carib\u00e9en" },
             { "xdr", "droit de tirage sp\u00e9cial" },
             { "xeu", "unit\u00e9 de compte europ\u00e9enne (ECU)" },
             { "xfo", "franc or" },
