@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -178,14 +178,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Casey = new String[] {
-               "\u00c0m Chasey",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Chile = new String[] {
                "Bun-\u00e0m na Sile",
                "",
@@ -220,11 +212,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "\u00c0m nan Innseachan",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Bun-\u00e0m na Seapaine",
@@ -324,11 +316,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Bun-\u00e0m nan Eileanan Asorach",
-               "HMT",
+               "",
                "T\u00ecde samhraidh nan Eileanan Asorach",
-               "HMT",
+               "",
                "\u00c0m nan Eileanan Asorach",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "\u00c0m But\u00e0in",
@@ -611,11 +603,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
             };
         final String[] Atlantic = new String[] {
-               "Bun-\u00e0m a\u2019 Chuain Siar",
+               "Bun-\u00e0m a\u2019 Chuain Shiar",
                "AST",
-               "T\u00ecde samhraidh a\u2019 Chuain Siar",
+               "T\u00ecde samhraidh a\u2019 Chuain Shiar",
                "ADT",
-               "\u00c0m a\u2019 Chuain Siar",
+               "\u00c0m a\u2019 Chuain Shiar",
                "AT",
             };
         final String[] Brasilia = new String[] {
@@ -738,6 +730,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Greenland = new String[] {
+               "Bun-\u00e0m na Graonlainne",
+               "",
+               "T\u00ecde samhraidh na Graonlainne",
+               "",
+               "\u00c0m na Graonlainne",
+               "",
+            };
         final String[] Hong_Kong = new String[] {
                "Bun-\u00e0m Hong Kong",
                "HKT",
@@ -850,6 +850,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "\u00c0m Casachst\u00e0in",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "\u00c0m nan Eileanan Sheiseall",
                "",
@@ -988,11 +996,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u00c0m Meadhan Afraga",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "\u00c0m Afraga an Ear",
@@ -1043,11 +1051,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "WET",
             };
         final String[] Mexico_Pacific = new String[] {
-               "Bun-\u00e0m a\u2019 Chuain S\u00e8imh Mheagsago",
+               "Bun-\u00e0m a\u2019 Chuain Sh\u00e8imh Mheagsago",
                "MST",
-               "T\u00ecde samhraidh a\u2019 Chuain S\u00e8imh Mheagsago",
+               "T\u00ecde samhraidh a\u2019 Chuain Sh\u00e8imh Mheagsago",
                "MDT",
-               "\u00c0m a\u2019 Chuain S\u00e8imh Mheagsago",
+               "\u00c0m a\u2019 Chuain Sh\u00e8imh Mheagsago",
                "MT",
             };
         final String[] Africa_Southern = new String[] {
@@ -1059,27 +1067,27 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "SAST",
             };
         final String[] America_Central = new String[] {
-               "Bun-\u00e0m Meadhan Aimeireaga a Tuath",
+               "Bun-\u00e0m Meadhan Aimeireaga",
                "CST",
-               "T\u00ecde samhraidh Meadhan Aimeireaga a Tuath",
+               "T\u00ecde samhraidh Meadhan Aimeireaga",
                "CDT",
-               "\u00c0m Meadhan Aimeireaga a Tuath",
+               "\u00c0m Meadhan Aimeireaga",
                "CT",
             };
         final String[] America_Eastern = new String[] {
-               "Bun-\u00e0m Aimeireaga a Tuath an Ear",
+               "Bun-\u00e0m Aimeireaga an Ear",
                "EST",
-               "T\u00ecde samhraidh Aimeireaga a Tuath an Ear",
+               "T\u00ecde samhraidh Aimeireaga an Ear",
                "EDT",
-               "\u00c0m Aimeireaga a Tuath an Ear",
+               "\u00c0m Aimeireaga an Ear",
                "ET",
             };
         final String[] America_Pacific = new String[] {
-               "Bun-\u00e0m a\u2019 Chuain S\u00e8imh",
+               "Bun-\u00e0m a\u2019 Chuain Sh\u00e8imh",
                "PST",
-               "T\u00ecde samhraidh a\u2019 Chuain S\u00e8imh",
+               "T\u00ecde samhraidh a\u2019 Chuain Sh\u00e8imh",
                "PDT",
-               "\u00c0m a\u2019 Chuain S\u00e8imh",
+               "\u00c0m a\u2019 Chuain Sh\u00e8imh",
                "PT",
             };
         final String[] French_Southern = new String[] {
@@ -1123,11 +1131,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Bun-\u00e0m Monadh Aimeireaga a Tuath",
+               "Bun-\u00e0m Monadh Aimeireaga",
                "MST",
-               "T\u00ecde samhraidh Monadh Aimeireaga a Tuath",
+               "T\u00ecde samhraidh Monadh Aimeireaga",
                "MDT",
-               "\u00c0m Monadh Aimeireaga a Tuath",
+               "\u00c0m Monadh Aimeireaga",
                "MT",
             };
         final String[] Marshall_Islands = new String[] {
@@ -1138,14 +1146,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Bun-\u00e0m Mheagsago an Iar-thuath",
-               "",
-               "T\u00ecde samhraidh Mheagsago an Iar-thuath",
-               "",
-               "\u00c0m Mheagsago an Iar-thuath",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "\u00c0m Gini Nuaidh Paputhaiche",
                "",
@@ -1172,27 +1172,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Bun-\u00e0m Astr\u00e0ilia an Iar",
-               "",
+               "AWST",
                "T\u00ecde samhraidh Astr\u00e0ilia an Iar",
-               "",
+               "AWDT",
                "\u00c0m Astr\u00e0ilia an Iar",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "Bun-\u00e0m na Graonlainn an Ear",
-               "",
-               "T\u00ecde samhraidh na Graonlainn an Ear",
-               "",
-               "\u00c0m na Graonlainn an Ear",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Bun-\u00e0m na Graonlainn an Iar",
-               "",
-               "T\u00ecde samhraidh na Graonlainn an Iar",
-               "",
-               "\u00c0m na Graonlainn an Iar",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "\u00c0m Meadhan nan Innd-Innse",
@@ -1218,22 +1202,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "\u00c0m Casachst\u00e0in an Ear",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Kazakhstan_Western = new String[] {
-               "\u00c0m Casachst\u00e0in an Iar",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "Bun-\u00e0m Meadhan Astr\u00e0ilia an Iar",
                "",
@@ -1270,54 +1238,196 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "T\u00ecde samhraidh Bhreatainn",
+                    "TSB",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
             { "BST", Bangladesh },
             { "CAT", Africa_Central },
+            { "CET", Europe_Central },
             { "CNT", Newfoundland },
             { "CST", America_Central },
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "EET", Europe_Eastern },
+            { "EST", America_Eastern },
+            { "HST",
+                new String[] {
+                    "Bun-\u00e0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                    "T\u00ecde Samhraidh nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HDT",
+                    "\u00c0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                }
+            },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
+            { "MET", Europe_Central },
             { "MIT", Apia },
+            { "MST", America_Mountain },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "WET", Europe_Western },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "Bun-\u00e0m na h-\u00c8ireann",
+                    "TS\u00c8 (\u00c8irinn)",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "T\u00ecde samhraidh Bhreatainn",
+                    "TSB",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Aqtau", Kazakhstan_Western },
+            { "Asia/Oral", Kazakhstan },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii",
+                new String[] {
+                    "Bun-\u00e0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                    "T\u00ecde Samhraidh nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HDT",
+                    "\u00c0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                }
+            },
+            { "Universal",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan },
             { "Asia/Anadyr", Anadyr },
-            { "Asia/Aqtobe", Kazakhstan_Western },
-            { "Asia/Atyrau", Kazakhstan_Western },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1329,12 +1439,21 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/Acre", Acre },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1342,8 +1461,10 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
+            { "America/Nuuk", Greenland },
             { "Asia/Baghdad", Arabian },
             { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
@@ -1352,7 +1473,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1360,6 +1482,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1377,6 +1500,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1404,10 +1528,25 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "\u00c0m Uile-choitcheann Co-\u00f2rdanaichte",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1420,7 +1559,16 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "T\u00ecde samhraidh Bhreatainn",
+                    "TSB",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1445,9 +1593,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10",
                 new String[] {
                     "Bun-\u00e0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
@@ -1483,15 +1633,24 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
-            { "Asia/Qyzylorda", Kazakhstan_Western },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1503,21 +1662,25 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1536,10 +1699,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
+            { "America/Godthab", Greenland },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1553,25 +1717,41 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "T\u00ecde samhraidh Bhreatainn",
+                    "TSB",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1582,10 +1762,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
             { "America/Eirunepe", Acre },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1596,10 +1778,11 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1611,6 +1794,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1621,9 +1805,19 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston",
+                new String[] {
+                    "Bun-\u00e0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                    "T\u00ecde Samhraidh nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HDT",
+                    "\u00c0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
+                    "HST",
+                }
+            },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1648,6 +1842,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1661,6 +1856,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1675,19 +1871,34 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Greenwich Mean Time",
+                    "GMT",
+                    "T\u00ecde samhraidh Bhreatainn",
+                    "TSB",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1705,6 +1916,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1715,10 +1928,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
+            { "America/Scoresbysund", Greenland },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1733,9 +1948,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1751,6 +1969,8 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Macau", "Mac\u00e0thu" },
             { "timezone.excity.Asia/Qatar", "Catar" },
             { "timezone.excity.Asia/Tokyo", "T\u014dky\u014d" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1766,6 +1986,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Riga", "R\u012bga" },
             { "timezone.excity.Europe/Rome", "An R\u00f2imh" },
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Baghdad", "Baghd\u0101d" },
             { "timezone.excity.Asia/Bahrain", "Bachrain" },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
@@ -1793,6 +2014,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Pacific/Nauru", "Nabhru" },
             { "timezone.excity.Pacific/Palau", "Palabh" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Belize", "A\u2019 Bheil\u00ecs" },
@@ -1835,7 +2057,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Kitts", "Naomh Cr\u00ecstean" },
             { "timezone.excity.America/St_Lucia", "Naomh L\u00f9isea" },
             { "timezone.excity.Atlantic/Bermuda", "Bearm\u00f9da" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Australia/Sydney", "Sidni" },
             { "timezone.excity.Europe/Gibraltar", "Diobraltar" },
             { "timezone.excity.Indian/Christmas", "Nollaig" },
@@ -1865,12 +2086,10 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Johannesburg", "Hannsaborgh" },
             { "timezone.excity.America/El_Salvador", "An Salbhador" },
             { "timezone.excity.America/Mexico_City", "Cathair Mheagsago" },
-            { "timezone.excity.America/Pangnirtung", "Pangniqtuuq" },
             { "timezone.excity.America/Puerto_Rico", "Porto R\u00ecceo" },
             { "timezone.excity.Atlantic/Cape_Verde", "An Ceap Uaine" },
             { "timezone.excity.Africa/Dar_es_Salaam", "D\u00e0r as-Sal\u00e0m" },
             { "timezone.excity.America/Rankin_Inlet", "Kangiqliniq" },
-            { "timezone.excity.America/Santa_Isabel", "Santa Isabel" },
             { "timezone.excity.Antarctica/Macquarie", "Eilean MhicGuaire" },
             { "timezone.excity.America/Port_of_Spain", "Port na Sp\u00e0inne" },
             { "timezone.excity.America/St_Barthelemy", "Saint Barth\u00e9lemy" },
